package com.ruoyi.oa.service;

import com.ruoyi.oa.domain.OaInsuranceTemplateDetail;
import com.ruoyi.oa.domain.vo.OaInsuranceTemplateDetailVo;
import com.ruoyi.oa.domain.bo.OaInsuranceTemplateDetailBo;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.core.domain.PageQuery;

import java.util.Collection;
import java.util.List;

/**
 * 社保/公积金模板明细Service接口
 *
 * @author ruoyi
 * @date 2025-06-23
 */
public interface IOaInsuranceTemplateDetailService {

    /**
     * 查询社保/公积金模板明细
     */
    OaInsuranceTemplateDetailVo queryById(Long insuranceDetailId);

    /**
     * 查询社保/公积金模板明细列表
     */
    TableDataInfo<OaInsuranceTemplateDetailVo> queryPageList(OaInsuranceTemplateDetailBo bo, PageQuery pageQuery);

    /**
     * 查询社保/公积金模板明细列表
     */
    List<OaInsuranceTemplateDetailVo> queryList(OaInsuranceTemplateDetailBo bo);

    /**
     * 新增社保/公积金模板明细
     */
    Boolean insertByBo(OaInsuranceTemplateDetailBo bo);

    /**
     * 修改社保/公积金模板明细
     */
    Boolean updateByBo(OaInsuranceTemplateDetailBo bo);

    /**
     * 校验并批量删除社保/公积金模板明细信息
     */
    Boolean deleteWithValidByIds(Collection<Long> ids, Boolean isValid);
}
